<?php

namespace XenGenTr\XenOneCikanKonular\Pub\Controller;

use XF\Mvc\ParameterBag;

class Thread extends XFCP_Thread

{
	public function actionIndex(ParameterBag $params)
	{
		$reply = parent::actionIndex($params);
		
		if (!$reply instanceof \XF\Mvc\Reply\View)
		{
			return $reply;
		}
		
		$thread = $reply->getParam('thread');
		
		$reply->setParam('onecikan', $this->repository('XenGenTr\XenOneCikanKonular:Onecikan')->fetchOnecikanByThread($thread));
		
		return $reply;
	}

	public function actionOneCikanDuzenle(ParameterBag $params)
	{
		if (!\XF::visitor()->hasPermission('OneCikanKonular_izinler', 'onecikan_gonder'))
		{
			return $this->noPermission();
		}
		
		$thread = $this->assertViewableThread($params->thread_id);
		$onecikan = $thread->Onecikan;
		
		if ($onecikan && !$onecikan->canEdit())
		{
			return $this->noPermission();
		}
		
		if ($this->isPost())
		{
			if (!$onecikan)
			{
				$onecikan = $this->em()->create('XenGenTr\XenOneCikanKonular:Onecikan');
			}
			
			if ($upload = $this->request->getFile('upload', false, false))
			{
				$this->repository('XenGenTr\XenOneCikanKonular:Onecikan')->setOnecikanFromUpload($thread, $upload);
			}
			
			$input = $this->filter('onecikan', 'array');
			$input['thread_id'] = $thread->thread_id;
			$input['onecikan_baslik'] = !empty($input['onecikan_baslik']) ? $input['fonecikan_baslik'] : '';
			$input['onecikan_icerik'] = !empty($input['onecikan_icerik']) ? $input['onecikan_icerik'] : '';
			
			$date = $this->filter('date', 'datetime');
			$time = $this->filter('time', 'str');
			list ($hour, $min) = explode(':', $time);
			
			$dateTime = new \DateTime('@'.$date);
			$dateTime->setTimeZone(\XF::language()->getTimeZone());
			$dateTime->setTime($hour, $min);
			$input['onecikan_tarih'] = $dateTime->getTimestamp();
			
			$form = $this->formAction();
			$form->basicEntitySave($onecikan, $input);
			$form->run();
			
			return $this->redirect($this->buildLink('threads', $thread));
		}
		
		$viewParams = [
			'thread' => $thread,
			'onecikan' => $onecikan,
		];
		
		return $this->view('XenGenTr\XenOneCikanKonular:Thread\OnecikanDuzenle', 'XenGenTr_OneCikanKonular_duzenle', $viewParams);
	}
	
	public function actionOneCikanSil(ParameterBag $params)
	{
		$onecikan = $this->assertOnecikanExists($params->thread_id, 'Thread');
		
		if (!$onecikan->canEdit())
		{
			return $this->noPermission();
		}
		
		if (!$onecikan->preDelete())
		{
			return $this->error($onecikan->getErrors());
		}

		if ($this->isPost())
		{
			$onecikan->delete();
			return $this->redirect($this->buildLink('threads', $onecikan));
		}
		else
		{
			$viewParams = [
				'onecikan' => $onecikan
			];
			return $this->view('XenGenTr\XenOneCikanKonular:OneCikan\Sil', 'XenGenTr_OneCikanKonulari_sil', $viewParams);
		}
	}	
	
	protected function assertOnecikanExists($id, $with = null, $phraseKey = null)
	{
		return $this->assertRecordExists('XenGenTr\XenOneCikanKonular:Onecikan', $id, $with, $phraseKey);
	}
}